﻿using Microsoft.Win32;
using System;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Controls.Primitives;
using System.Windows.Input;
using System.Windows.Media.Imaging;
using System.Windows.Threading;

namespace UkazkaMediaElement
{
    /// <summary>
    /// Interakční logika pro MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        private Boolean hraje = false;
        private Boolean posun = false;
        private DispatcherTimer timer = new DispatcherTimer();
        private double rychlost = 1;
        public Boolean zastaveno = false;


        /// <summary>
        /// Konstruktor třídy
        /// </summary>
        /// <param name="index"></param>
        public MainWindow()
        {
            InitializeComponent();
            NastavTlacitka(0);
            grOvladani.Visibility = Visibility.Hidden;

            timer.Interval = TimeSpan.FromSeconds(1);
            timer.Tick += timer_Tick;
            timer.Start();

            sdrHlasitost.Value = mePrehravac.Volume;
        }


        #region Procedury okna =======================================
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void ZavriOkno(object sender, RoutedEventArgs e)
        {
            wdwPrvky.Close();
        }


        /// <summary>
        /// Časovač
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void timer_Tick(object sender, EventArgs e)
        {
            if ((mePrehravac.Source != null) && (mePrehravac.NaturalDuration.HasTimeSpan) && (!posun))
            {
                sdrUkazatel.Minimum = 0;
                sdrUkazatel.Maximum = mePrehravac.NaturalDuration.TimeSpan.TotalSeconds;
                sdrUkazatel.Value = mePrehravac.Position.TotalSeconds;
            }
        }


        /// <summary>
        /// Zobrazení ovládací lišty (po najetí myši)
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void ZobrazTlacitka(object sender, MouseEventArgs e)
        {
            grOvladani.Visibility = Visibility.Visible;
        }


        /// <summary>
        /// Skytí ovládací lišty
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void SkryjTlacitka(object sender, MouseEventArgs e)
        {
            grOvladani.Visibility = Visibility.Hidden;
        }


        /// <summary>
        /// Nastavení přístupu na tlačítka
        /// </summary>
        /// <param name="status"></param>
        private void NastavTlacitka(int status)
        {
            switch (status)
            {
                case 0:
                    sdrUkazatel.IsEnabled = false;
                    sdrUkazatel.Opacity = 0.5;
                    sdrHlasitost.IsEnabled = false;
                    sdrHlasitost.Opacity = 0.5;
                    btnPlay.IsEnabled = false;
                    btnPlay.Opacity = 0.5;
                    btnStop.IsEnabled = false;
                    btnStop.Opacity = 0.5;
                    btnMoveBack.IsEnabled = false;
                    btnMoveBack.Opacity = 0.5;
                    btnMoveForward.IsEnabled = false;
                    btnMoveForward.Opacity = 0.5;
                    btnPomalu.IsEnabled = false;
                    btnPomalu.Opacity = 0.5;
                    btnRychle.IsEnabled = false;
                    btnRychle.Opacity = 0.5;
                    btnNormalne.IsEnabled = false;
                    btnNormalne.Opacity = 0.5;
                    break;
                case 1:
                    sdrUkazatel.IsEnabled = false;
                    sdrUkazatel.Opacity = 0.5;
                    sdrHlasitost.IsEnabled = false;
                    sdrHlasitost.Opacity = 0.5;
                    btnPlay.IsEnabled = true;
                    btnPlay.Opacity = 1;
                    btnStop.IsEnabled = false;
                    btnStop.Opacity = 0.5;
                    btnMoveBack.IsEnabled = false;
                    btnMoveBack.Opacity = 0.5;
                    btnMoveForward.IsEnabled = false;
                    btnMoveForward.Opacity = 0.5;
                    btnPomalu.IsEnabled = false;
                    btnPomalu.Opacity = 0.5;
                    btnRychle.IsEnabled = false;
                    btnRychle.Opacity = 0.5;
                    btnNormalne.IsEnabled = false;
                    btnNormalne.Opacity = 0.5;
                    break;
                case 2:
                    sdrUkazatel.IsEnabled = true;
                    sdrUkazatel.Opacity = 1;
                    sdrHlasitost.IsEnabled = true;
                    sdrHlasitost.Opacity = 1;
                    btnPlay.IsEnabled = true;
                    btnPlay.Opacity = 1;
                    btnStop.IsEnabled = true;
                    btnStop.Opacity = 1;
                    btnMoveBack.IsEnabled = true;
                    btnMoveBack.Opacity = 1;
                    btnMoveForward.IsEnabled = true;
                    btnMoveForward.Opacity = 1;
                    btnPomalu.IsEnabled = true;
                    btnPomalu.Opacity = 1;
                    btnRychle.IsEnabled = true;
                    btnRychle.Opacity = 1;
                    btnNormalne.IsEnabled = true;
                    btnNormalne.Opacity = 1;
                    break;
                default:
                    break;
            }
        }


        /// <summary>
        /// Zavření okna
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void Zavri(object sender, System.ComponentModel.CancelEventArgs e)
        {
            UkonciPrehravani();
        }


        /// <summary>
        /// Zavření okna
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void BtnZavri(object sender, RoutedEventArgs e)
        {
            UkonciPrehravani();
            wdwPrvky.Close();
        }


        /// <summary>
        /// Ukončení přehrávání
        /// </summary>
        private void UkonciPrehravani()
        {
            if (hraje == false)
            {
                mePrehravac.Position = TimeSpan.Zero;
            }
            else
            {
                mePrehravac.Position = mePrehravac.Position;
            }
            if (timer != null)
            {
                timer.Stop();
            }
            mePrehravac.Stop();
            mePrehravac.Close();
        }
        #endregion



        #region Procedury Slideru ====================================
        /// <summary>
        /// Slider start
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void SdrU_Start(object sender, DragStartedEventArgs e)
        {
            posun = true;
        }


        /// <summary>
        /// Slider konec
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void SdrU_Konec(object sender, DragCompletedEventArgs e)
        {
            posun = false;
            mePrehravac.Position = TimeSpan.FromSeconds(sdrUkazatel.Value);
        }


        /// <summary>
        /// Slider změna
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void SdrU_Zmena(object sender, RoutedPropertyChangedEventArgs<double> e)
        {
            tbkCas.Text = TimeSpan.FromSeconds(sdrUkazatel.Value).ToString(@"hh\:mm\:ss");
            tbkCelkCas.Text = TimeSpan.FromSeconds(sdrUkazatel.Maximum).ToString(@"hh\:mm\:ss");
        }


        /// <summary>
        /// Nastavení hlasitosti
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void SdrHlas_Zmena(object sender, RoutedPropertyChangedEventArgs<double> e)
        {
            mePrehravac.Volume = sdrHlasitost.Value;
            if (sdrHlasitost.Value == 0)
            {
                BitmapImage obr = new BitmapImage(
                            new Uri("pack://application:,,,/UkazkaMediaElement;component/Obr/bezZvuku.png"));
                imgObr.ImageSource = obr;
            }
            else
            {
                BitmapImage obr = new BitmapImage(
                            new Uri("pack://application:,,,/UkazkaMediaElement;component/Obr/zvuk.png"));
                imgObr.ImageSource = obr;
            }
        }
        #endregion



        #region Procedury videa ======================================
        /// <summary>
        /// Výběr videa
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void BtnOtevri(object sender, RoutedEventArgs e)
        {
            OpenFileDialog openFileDialog = new OpenFileDialog();
            openFileDialog.Filter = "Video soubory (*.mpg;*.mpeg;*.avi;*.mp4)|*.mpg;*.mpeg;*.avi;*.mp4";
            if (openFileDialog.ShowDialog() == true)
            {
                ZrusPrehravani();
                mePrehravac.Source = new Uri(openFileDialog.FileName);
                lblSoubor.Content = openFileDialog.FileName;
                NastavTlacitka(1);
            }
        }


        /// <summary>
        /// Spuštění nebo pozastavení videa
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void BtnPrehraj(object sender, RoutedEventArgs e)
        {
            timer.Start();
            if (hraje == false)
            {
                Prehraj();
                NastavTlacitka(3);
                zastaveno = false;
            }
            else
            {
                Pozastav();
                NastavTlacitka(1);
            }
        }


        /// <summary>
        /// Ukončení přehrávání videa
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void BtnStop(object sender, RoutedEventArgs e)
        {
            if (timer != null)
            {
                timer.Stop();
            }
            mePrehravac.Stop();
            sdrUkazatel.Value = 0;
            hraje = false;
            btnPlay.SetResourceReference(Button.StyleProperty, "Prehraj");
            btnPlay.ToolTip = "Přehrát video";
            NastavTlacitka(1);
            zastaveno = true;
        }


        /// <summary>
        /// Přehraje video
        /// </summary>
        private void Prehraj()
        {
            mePrehravac.Play();
            hraje = true;
            btnPlay.SetResourceReference(Button.StyleProperty, "Pause");
            btnPlay.ToolTip = "Pozastavit video";
            NastavTlacitka(2);
        }


        /// <summary>
        /// Pozastaví video
        /// </summary>
        private void Pozastav()
        {
            mePrehravac.Pause();
            hraje = false;
            btnPlay.SetResourceReference(Button.StyleProperty, "Prehraj");
            btnPlay.ToolTip = "Přehrát video";
            NastavTlacitka(1);
        }


        /// <summary>
        /// Posun videa vzad
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void BtnZpet(object sender, RoutedEventArgs e)
        {
            mePrehravac.Position -= TimeSpan.FromSeconds(10);
        }


        /// <summary>
        /// Posun videa vpřed
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void BtnVpred(object sender, RoutedEventArgs e)
        {
            mePrehravac.Position += TimeSpan.FromSeconds(10);

        }


        /// <summary>
        /// Pomalé přehrávání
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void BtnPomalu(object sender, RoutedEventArgs e)
        {
            int aktRychlost = 0;
            if (rychlost > 1)
            {
                rychlost -= rychlost / 2;
                mePrehravac.SpeedRatio = rychlost;
            }
            else
            {
                if (rychlost == 1)
                {
                    rychlost -= 0.2;
                    mePrehravac.SpeedRatio = rychlost;
                }
                else
                {
                    aktRychlost = (int)(rychlost * 10);
                    if (aktRychlost > 2)
                    {
                        rychlost -= 0.2;
                        mePrehravac.SpeedRatio = rychlost;
                    }
                }
            }
            tbkRychlost.Text = rychlost.ToString();
        }


        /// <summary>
        /// Rychlé přehrávání
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void BtnRychle(object sender, RoutedEventArgs e)
        {
            if (rychlost >= 1 && rychlost < 32)
            {
                rychlost += rychlost;
                mePrehravac.SpeedRatio = rychlost;
            }
            else
            {
                if (rychlost < 1)
                {
                    rychlost += 0.2;
                    mePrehravac.SpeedRatio = rychlost;
                }
            }
            tbkRychlost.Text = rychlost.ToString();
        }


        /// <summary>
        /// Normální přehrávání
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void BtnNormalne(object sender, RoutedEventArgs e)
        {
            rychlost = 1;
            mePrehravac.SpeedRatio = rychlost;
            tbkRychlost.Text = rychlost.ToString();
        }


        /// <summary>
        /// Procedura při dosažení konce videa
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void NastavKonec(object sender, RoutedEventArgs e)
        {
            mePrehravac.Stop();
            sdrUkazatel.Value = 0;
            sdrUkazatel.Refresh();
            hraje = false;
            posun = false;
            zastaveno = false;
            btnPlay.SetResourceReference(Button.StyleProperty, "Prehraj");
            btnPlay.ToolTip = "Přehrát video";
            NastavTlacitka(1);
        }


        /// <summary>
        /// Zrušení přehrávání videa
        /// </summary>
        private void ZrusPrehravani()
        {
            mePrehravac.Stop();
            mePrehravac.Close();
            sdrUkazatel.Value = 0;
            sdrUkazatel.Refresh();
            tbkCas.Text = "00:00:00";
            tbkCelkCas.Text = "00:00:00";
            tbkRychlost.Text = "1";
            rychlost = 1;
            mePrehravac.SpeedRatio = rychlost;
            hraje = false;
            posun = false;
            zastaveno = false;
            btnPlay.SetResourceReference(Button.StyleProperty, "Prehraj");
            btnPlay.ToolTip = "Přehrát video";
            NastavTlacitka(0);
        }
        #endregion
    }
}
