﻿using System;
using System.IO;
using System.Windows;
using System.Windows.Controls;

namespace UkazkaTreeView
{
    /// <summary>
    /// Interakční logika pro MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        private string aktAdr = "";
        private string vybrano = null;
        private RadekStromu treeVybrano = null;

        
        /// <summary>
        /// Konstruktor třídy
        /// </summary>
        public MainWindow()
        {
            InitializeComponent();
            NactiData();
        }


        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void ZavriOkno(object sender, RoutedEventArgs e)
        {
            wdwPrvky.Close();
        }


        /// <summary>
        /// Zobrazení výběru z jednoduchého stromu
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void ZobrazVyber1(object sender, RoutedPropertyChangedEventArgs<object> e)
        {
            var tv = sender as TreeView;
            if (tv != null)
            {
                if (tv.Parent != null)
                {
                    TreeViewItem tvi = new TreeViewItem();
                    tvi = tv.SelectedItem as TreeViewItem;
                    if (String.IsNullOrEmpty(tvi.Uid))
                    {
                        lblVybrano1.Content = tvi.Header;
                    }
                    else
                    {
                        lblVybrano1.Content = "";
                    }
                }
            }
        }


        #region Strom, naplněný programově =====================================
        /// <summary>
        /// Naplnění stromu seznamem disků
        /// </summary>
        private void NactiData()
        {
            tvwAdresare.Items.Clear();
            DriveInfo[] disky = DriveInfo.GetDrives();
            foreach (DriveInfo disk in disky)
            {
                RadekStromu psDisk = new RadekStromu();
                psDisk.Header = disk.Name;
                psDisk.Path = disk.Name;
                psDisk.Type = disk.GetType().Name;
                psDisk.Items.Add("Plním...");
                psDisk.Expanded += new RoutedEventHandler(Rozbal);
                psDisk.SetResourceReference(TreeViewItem.StyleProperty, "Hlavicka");
                tvwAdresare.Items.Add(psDisk);
            }
        }


        /// <summary>
        /// Rozbalení řádku stromu
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void Rozbal(object sender, RoutedEventArgs e)
        {
            RadekStromu tvi = (RadekStromu)sender;
            VytvorRadekStromu(tvi);
            e.Handled = true;
        }


        /// <summary>
        /// Vytvoření řádku stromu
        /// </summary>
        /// <param name="radek"></param>
        private void VytvorRadekStromu(RadekStromu radek)
        {
            DirectoryInfo di = new DirectoryInfo(radek.Path);
            radek.Items.Clear();

            foreach (DirectoryInfo adr in di.GetDirectories())
            {
                var skryty = (adr.Attributes & FileAttributes.Hidden) == FileAttributes.Hidden;
                var systemovy = (adr.Attributes & FileAttributes.System) == FileAttributes.System;
                if (!skryty && !systemovy)
                {
                    RadekStromu tvi = new RadekStromu();
                    tvi.Header = adr.Name;
                    tvi.Path = adr.FullName;
                    tvi.Type = adr.GetType().Name;
                    tvi.Expanded += new RoutedEventHandler(Rozbal);
                    tvi.SetResourceReference(TreeViewItem.StyleProperty, "Polozka");
                    try
                    {
                        foreach (DirectoryInfo adresar in adr.GetDirectories())
                        {
                            RadekStromu ps = new RadekStromu();
                            ps.Expanded += new RoutedEventHandler(Rozbal);
                            ps.Header = adresar.Name;
                            ps.Path = adr.FullName;
                            ps.Type = adresar.GetType().Name;
                            tvi.Items.Add(ps);
                        }
                        radek.Items.Add(tvi);
                    }
                    catch (Exception)
                    {

                    }
                }
            }
        }


        /// <summary>
        /// Čti adresáře
        /// </summary>
        /// <param name="psV"></param>
        public void CtiAdresare(RadekStromu psV)
        {
            if (!String.IsNullOrEmpty(psV.Path))
            {
                VytvorRadekStromu(psV);
                psV.IsExpanded = true;

                foreach (RadekStromu ps2 in psV.Items)
                {
                    if (aktAdr.IndexOf(ps2.Path) > -1)
                    {
                        ps2.IsSelected = true;
                        lblVybrano2.Content = ps2.Path;
                        CtiAdresare(ps2);
                    }
                }
            }
        }


        /// <summary>
        /// Vyber označený adresář
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void VyberAdresar(object sender, RoutedPropertyChangedEventArgs<object> e)
        {
            if (e.NewValue != null)
            {
                TreeViewItem vybr = tvwAdresare.SelectedItem as TreeViewItem;
                treeVybrano = tvwAdresare.SelectedItem as RadekStromu;

                RadekStromu ps = (RadekStromu)e.NewValue;
                lblVybrano2.Content = ps.Path;
                vybrano = ps.Path;
            }
            e.Handled = true;
        }
        #endregion
    }


    /// <summary>
    /// Struktura záznamu stromu
    /// </summary>
    public class RadekStromu : TreeViewItem
    {
        public string Path { get; set; }
        public string Type { get; set; }
    }
}
